<?php

namespace App\Http\Controllers;

use App\Http\Requests\ProfileUpdateRequest;
use App\Models\Department;
use App\Models\User;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\View\View;

class ProfileController extends Controller
{

    public function index(){
        $users = User::paginate();
        return view('dashboard',compact('users'));
    }
    /**
     * Display the user's profile form.
     */
    public function edit(Request $request,User $user): View
    {
        return view('profile.edit', [
            'user' => $user,
            'departments' => Department::all()
        ]);
    }

    /**
     * Update the user's profile information.
     */
    public function update(ProfileUpdateRequest $request,User $user) #: RedirectResponse
    {
        $user = $user->fill($request->validated());
        if (isset($request->is_manager)) {
            $user->assignRole('manager');
        }else{
            $user->removeRole('manager');
        }
        $user->save();
        return Redirect::route('profile.index')->with('status', 'profile-updated');
    }

    /**
     * Delete the user's account.
     */
    public function destroy(Request $request,User $user): RedirectResponse
    {
        $user->delete();
        return Redirect::to('profiles');
    }
}
