<?php

use App\Http\Middleware\SetElfinderConfig;
use App\Models\FileEvent;
use Illuminate\Support\Facades\Auth;

return array(

    /*
    |--------------------------------------------------------------------------
    | Upload dir
    |--------------------------------------------------------------------------
    |
    | The dir where to store the images (relative from public)
    |
    */
    'dir' => ['shared'],

    /*
    |--------------------------------------------------------------------------
    | Filesystem disks (Flysytem)
    |--------------------------------------------------------------------------
    |
    | Define an array of Filesystem disks, which use Flysystem.
    | You can set extra options, example:
    |
    | 'my-disk' => [
    |        'URL' => url('to/disk'),
    |        'alias' => 'Local storage',
    |    ]
    */
    'disks' => [],

    /*
    |--------------------------------------------------------------------------
    | Routes group config
    |--------------------------------------------------------------------------
    |
    | The default group settings for the elFinder routes.
    |
    */

    'route' => [
        'prefix' => 'files',
        'middleware' => array('web', 'auth', 'elfinder.access', SetElfinderConfig::class),
    ],

    /*
    |--------------------------------------------------------------------------
    | Access filter
    |--------------------------------------------------------------------------
    |
    | Filter callback to check the files
    |
    */

    'access' => 'Barryvdh\Elfinder\Elfinder::checkAccess',

    /*
    |--------------------------------------------------------------------------
    | Roots
    |--------------------------------------------------------------------------
    |
    | By default, the roots file is LocalFileSystem, with the above public dir.
    | If you want custom options, you can set your own roots below.
    |
    */

    'roots' => null,



    /*
    |--------------------------------------------------------------------------
    | Options
    |--------------------------------------------------------------------------
    |
    | These options are merged, together with 'roots' and passed to the Connector.
    | See https://github.com/Studio-42/elFinder/wiki/Connector-configuration-options-2.1
    |
    */

    'options' => array(
        'bind' => [
            'mkdir mkfile rename duplicate upload rm paste upload' =>
            function ($cmd, $result, $args, $elfinder, $volume) {
                $userId = Auth::id();
                $eventType = strtoupper($cmd);

                foreach ($result as $key => $value) {
                    if (empty($value)) {
                        continue;
                    }

                    if (is_array($value)) {
                        foreach ($value as $file) {
                            if (is_array($file)) {
                                $filePath = $file['realpath'] ?? (isset($file['hash']) ? $elfinder->realpath($file['hash']) : null);
                                $oldPath = $file['oldpath'] ?? null;
                                $fileName = $file['name'] ?? null;
                                $fileSize = $file['size'] ?? null;

                                if ($filePath && $fileName !== null) {
                                    FileEvent::create([
                                        'event_type' => $eventType,
                                        'file_name'  => $fileName,
                                        'file_path'  => $filePath,
                                        // 'old_path'   => $oldPath,
                                        'file_size'  => $fileSize,
                                        'user_id'    => $userId,
                                    ]);
                                }
                                // logger([$file]);
                            }
                        }
                    }
                }
            }
        ],
    ),

    /*
    |--------------------------------------------------------------------------
    | Root Options
    |--------------------------------------------------------------------------
    |
    | These options are merged, together with every root by default.
    | See https://github.com/Studio-42/elFinder/wiki/Connector-configuration-options-2.1#root-options
    |
    */
    'root_options' => array(),

);
