<?php

namespace Database\Factories;

use App\Models\User;
use Illuminate\Database\Eloquent\Factories\Factory;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Models\Role;

class UserFactory extends Factory
{
    protected $model = User::class;

    public function definition()
    {
        return [
            'name' => $this->faker->name,
            'file_no' => $this->faker->unique()->uuid,
            'email' => $this->faker->unique()->safeEmail,
            'email_verified_at' => now(),
            'password' => Hash::make('password'), // Default password for testing
            'remember_token' => \Str::random(10),
        ];
    }

    // Define a state for Admin role
    public function admin()
    {
        return $this->afterCreating(function (User $user) {
            $user->assignRole('manager'); // Assign the 'admin' role
        });
    }

    // Define a state for Team Member role
    public function teamMember()
    {
        return $this->afterCreating(function (User $user) {
            $user->assignRole('team_member'); // Assign the 'team_member' role
        });
    }

    // Define a state for Auditor role
    public function auditor()
    {
        return $this->afterCreating(function (User $user) {
            $user->assignRole('auditor'); // Assign the 'auditor' role
        });
    }
}
